#!/bin/sh
# Distro Varible define for Distro-Installer line
user=`whoami | gawk 'BEGIN{RS="[[:space:]]";FS=OFS=""}{$1=toupper($1);ORS=RT}1'`
distro="Unity"
desktop="`xdg-user-dir DESKTOP 2>/dev/null`"
if test -z "$desktop"; then
    desktop=$HOME/Desktop
fi

#
# do we run in a prelinked system ?
#
if test -f /etc/sysconfig/prelink; then
. /etc/sysconfig/prelink
  if test "$USE_PRELINK" = "yes" ; then
     KDE_IS_PRELINKED=1
     export KDE_IS_PRELINKED
  else
     unset KDE_IS_PRELINKED
  fi
fi

# 
# workaround SaX/SUSE bug that doesn't setup a proper keyboard map
#

if [ -f /usr/share/hotkey-setup/hotkey-setup.xmodmap ]; then
  xmodmap /usr/share/hotkey-setup/hotkey-setup.xmodmap
fi

#
# Do we have a special Gtk theming for our Qt widget theme ?
#
if [ ! -e $HOME/.no-qtrc-to-gtkrc-mapping ]; then
  UNITY_VERSION="`cat /etc/unity-release | sed -n 's/VERSION = //p'`"

    GTK2_SYSCONFDIR=/etc
    GTK2_DATADIR=/usr/share/themes/

  # use general gtk-qt-engine
  if [ -e "$GTK2_DATADIR/Qt/gtk-2.0/gtkrc" ] ; then
    GTK2_THEME_RC="$GTK2_DATADIR/Qt/gtk-2.0/gtkrc"
  else
    # use QtCurve engine
    if [ -e "$GTK2_DATADIR/QtCurve/gtk-2.0/gtkrc" ] ; then
       GTK2_THEME_RC="$GTK2_DATADIR/QtCurve/gtk-2.0/gtkrc"
    fi
  fi

  # GTK2
  # NOTE: ~/.gtkrc-2.0-kde is added later (in latest KDE only)
  if [ "$GTK2_RC_FILES" ]; then
    export GTK2_RC_FILES="$GTK2_RC_FILES:$GTK2_THEME_RC:$HOME/.gtkrc-2.0-qtengine:$HOME/.gtkrc-2.0"
  else
    export GTK2_RC_FILES="$GTK2_SYSCONFDIR/gtk-2.0/gtkrc:$GTK2_THEME_RC:$HOME/.gtkrc-2.0-qtengine:$HOME/.gtkrc-2.0"
  fi

fi

if [ -r /etc/sysconfig/windowmanager ]; then
  # Do the user want the SuSE theme ?
  source /etc/sysconfig/windowmanager

  # Should we really enable FAM support for KDE ?
  export USE_FAM="$KDE_USE_FAM"

  # Disable IPv6 ?
  if [ "$KDE_USE_IPV6" = "no" ]; then
     export KDE_NO_IPV6=1
  fi
  # Disable IDN ?
  if [ "$KDE_USE_IDN" = "no" ]; then
     export KDE_NO_IDN=1
  fi

else
  if [ -r /etc/rc.config ]; then
    # Do the user want the SuSE theme ?
    INSTALL_DESKTOP_EXTENSIONS=`bash -c "source /etc/rc.config && echo \\$INSTALL_DESKTOP_EXTENSIONS"`

    # Should we really enable FAM support for KDE ?
    USE_FAM=`bash -c "source /etc/rc.config && echo \\$KDE_USE_FAM"`
    export USE_FAM
  fi
fi

#
# create Unity defaults
#
if [ ! -e "$HOME/.skel/kdebase" ]; then
    mkdir -p "$desktop"

    if [ -e "/usr/bin/firefox" -a ! -e "$desktop/firefox.desktop" -a -e "/usr/share/applications/firefox.desktop" ]; then
          cp /usr/share/applications/firefox.desktop "$desktop/"
    fi
    chmod u+x "$desktop/firefox.desktop" 2>/dev/null

# If running Live Copy Live Installer to Desktop
    if [ -e "/initrd/linuxrc" -a ! -e "$desktop/$distro-Installer.desktop" ]; then
          cp "/usr/share/config/Unity/default/$distro-Installer.desktop" "$desktop/"
    fi
    chmod u+x "$desktop/$distro-Installer.desktop" 2>/dev/null

    if [ -e "/usr/bin/oofromtemplate" -a  ! -e "$desktop/Office.desktop" -a -e "/usr/share/config/Unity/default/Office.desktop" ]; then
          cp /usr/share/config/Unity/default/Office.desktop "$desktop/"
    fi
    chmod u+x "$desktop/Office.desktop" 2>/dev/null

    if [ ! -e "$desktop/Support.desktop" -a -e "/usr/share/config/Unity/default/Support.desktop" ]; then
          cp /usr/share/config/Unity/default/Support.desktop "$desktop/"
    fi
    sed -i 's/^Icon=helpcenter$/Icon=Support/' "$desktop/Support.desktop"
    chmod u+x "$desktop/Support.desktop" 2>/dev/null
    
    if [ ! -e "$desktop/Home2.desktop" -a -e "/usr/share/config/Unity/default/Home2.desktop" ]; then
	  cp /usr/share/config/Unity/default/Home2.desktop "$desktop/"
    fi
    sed -i "s/^Name=Home$/Name="$user"'s Files/" "$desktop/Home2.desktop"
    chmod u+x "$desktop/Home2.desktop" 2>/dev/null

    if [ ! -e "$desktop/myComputer.desktop" -a -e "/usr/share/config/Unity/default/myComputer.desktop" ]; then
          cp /usr/share/config/Unity/default/myComputer.desktop "$desktop/"
    fi
    chmod u+x "$desktop/myComputer.desktop" 2>/dev/null
# Clean the Desktop of Default Unity applications if they're no longer installed
# - Is Sakura Installed? If Not remove Desktop icon
    if [ ! -e /usr/bin/sakura -a -e $desktop/sakura.desktop ]; then
	  rm -f $desktop/sakura.desktop
    else
          chmod u+x "$desktop/sakura.desktop" 2>/dev/null
    fi
# - Is Scite Installed? If Not remove Desktop icon
    if [ ! -e /usr/bin/scite -a -e $desktop/scite.desktop ]; then
	  rm -f $desktop/scite.desktop
    else
	  chmod u+x "$desktop/scite.desktop"
    fi
# Halt Icon should no longer be needed on the Desktop remove if it's there
    if [ -e $desktop/halt.desktop ]; then
	  rm -f $desktop/halt.desktop
    fi
# Logout Icon should no longer be needed on the Desktop remove if it's there
    if [ -e $desktop/lxde-logout.desktop ]; then
	  rm -f $desktop/lxde-logout.desktop
    fi
# Make Unity Control Center a trusted application by default if on the Desktop
    if [ -e $desktop/Unity-drakconf.desktop ]; then
	  chmod u+x "$desktop/Unity-drakconf.desktop" 2>/dev/null
    fi
# Make Smart Package Manager a trusted application by default if on the Desktop
    if [ -e $desktop/smart-package-manager.desktop ]; then
	  chmod u+x "$desktop/smart-package-manager.desktop" 2>/dev/null
    fi
# Copy Over user Specific Configs
# - Copy over and set Locale in kdeglobals
    if [ ! -e $HOME/.kde4/share/config/kdeglobals -a -e /usr/share/config/$distro/default/kdeglobals ]; then
          mkdir -p $HOME/.kde4/share/config
          cp /usr/share/config/Unity/default/kdeglobals $HOME/.kde4/share/config/kdeglobals
          # add Language= and Country=
          local=`/usr/bin/locale 2>&1 | grep LC_MESSAGES | sed -e 's#^LC_MESSAGES="\(.*\)"$#\1#; s#\..*##'`
          lang=`echo $local | sed -e 's,_.*$,,'`
          countr=`echo $local | sed -e 's,^.*_,,' | tr 'A-Z' 'a-z'`
          if test -z "$countr"; then countr=$lang; fi
          cat >>$HOME/.kde4/share/config/kdeglobals <<EOF
[Locale]
Country=$countr
Language=$lang
EOF
    fi

    if [ ! -e $HOME/.kde4/share/config/kcminputrc -a -e /usr/share/config/Unity/default/kcminputrc ]; then
          mkdir -p $HOME/.kde4/share/config
          cp /usr/share/config/Unity/default/kcminputrc $HOME/.kde4/share/config/kcminputrc
    fi

    if [ ! -e $HOME/.kde4/share/config/nepomukserverrc -a -e /usr/share/config/Unity/default/nepomukserverrc ]; then
          mkdir -p $HOME/.kde4/share/config
          cp /usr/share/config/Unity/default/nepomukserverrc $HOME/.kde4/share/config/nepomukserverrc
    fi

    if [ ! -e "$HOME/.kde4/share/apps/konqueror/bookmarks.xml" -a -e "/usr/share/config/Unity/default/bookmarks.xml" ]; then
          mkdir -p $HOME/.kde4/share/apps/konqueror
          cp /usr/share/config/Unity/default/bookmarks.xml $HOME/.kde4/share/apps/konqueror/bookmarks.xml
    fi

# Create Home Folders with XDG and make sure the folder icons are what we want
#--------------------------------------------------------------------------------------------------------------
# Documents
    mkdir -p $HOME/Documents
    documents="`xdg-user-dir DOCUMENTS 2>/dev/null`"
    if test -z "$documents"; then
        documents=$HOME/Documents
    fi
    if [ ! -e "$documents/.directory" -a -e "/usr/share/config/$distro/default/documents.directory" ]; then
          cp /usr/share/config/$distro/default/documents.directory "$documents/.directory"
    fi
#--------------------------------------------------------------------------------------------------------------
# Download
    mkdir -p $HOME/Download
    download="`xdg-user-dir DOWNLOAD 2>/dev/null`"
    if test -z "$download"; then
	download=$HOME/Download
    fi
    if [ ! -e "$download/.directory" -a -e "/usr/share/config/$distro/default/download.directory" ]; then
          cp /usr/share/config/$distro/default/download.directory "$download/.directory"
    fi
#-------------------------------------------------------------------------------------------------------------
# Music
    mkdir -p $HOME/Music
    music="`xdg-user-dir MUSIC 2>/dev/null`"
    if test -z "$music"; then
        music=$HOME/Music
    fi
    if [ ! -e "$music/.directory" -a -e "/usr/share/config/$distro/default/music.directory" ]; then
          cp /usr/share/config/$distro/default/music.directory "$music/.directory"
    fi
#-------------------------------------------------------------------------------------------------------------
# Videos
    mkdir -p $HOME/Videos
    videos="`xdg-user-dir VIDEOS 2>/dev/null`"
    if test -z "$videos"; then
        videos=$HOME/Videos
    fi
    if [ ! -e "$videos/.directory" -a -e "/usr/share/config/$distro/default/videos.directory" ]; then
          cp /usr/share/config/$distro/default/videos.directory "$videos/.directory"
    fi
#-------------------------------------------------------------------------------------------------------------
# Pictures
    mkdir -p $HOME/Pictures
    pictures="`xdg-user-dir PICTURES 2>/dev/null`"
    if test -z "$pictures"; then
        pictures=$HOME/Pictures
    fi
    if [ ! -e "$pictures/.directory" -a -e "/usr/share/config/$distro/default/pictures.directory" ]; then
          cp /usr/share/config/$distro/default/pictures.directory "$pictures/.directory"
    fi
#-------------------------------------------------------------------------------------------------------------

    mkdir -p $HOME/.skel/
    touch $HOME/.skel/kdebase
fi

# check if any rpms have been (un)installed since ksycoca
# had been built, if yes, trigger ksycoca rebuild immediatelly
# instead of delayed

kdehome=$HOME/.kde4
test -n "$KDEHOME" && kdehome=`echo "$KDEHOME"|sed "s,^~/,$HOME/,"`
host=$HOSTNAME
test -n "$XAUTHLOCALHOSTNAME" && host=$XAUTHLOCALHOSTNAME
ksycoca="$kdehome/cache-$host/ksycoca"

if test -f "$ksycoca"; then
    if test -f /var/lib/rpm/Packages; then
	if test /var/lib/rpm/Packages -nt "$ksycoca"; then
	    rm -f "$ksycoca"
	fi
    fi
fi
